#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Project       FreeImagePy
# file name:    constants.py
# Version:      1.0.0
#
# DESCRIPTION
# FreeImage python bind - constants and exceptions file
#
# Developer:
# Michele Petrazzo <michele.petrazzo@unipex.it>
#
# History :
# creation: 08/2005 - Michele Petrazzo
# 
# License:
#         GNU General Public License (GPL)
#         FreeImage Public License (FIPL)
#         For more info see LICENSE.txt
#
# Copyright (C) 2005  Unipex s.r.l.,  All Rights Reserved.
# Via Vittorio Veneto 83/A
# 33050 Gonars (UD) - Italy
# tel. +39 0432 931511 - fax +39 0432 931378
# www.unipex.it - michele.petrazzo@unipex.it
#

import ctypes as C

#Bitmap types
FIF_UNKNOWN     = -1
FIF_BMP		= 0
FIF_ICO		= 1
FIF_JPEG	= 2
FIF_JNG		= 3
FIF_KOALA	= 4
FIF_LBM		= 5
FIF_IFF = FIF_LBM
FIF_MNG		= 6
FIF_PBM		= 7
FIF_PBMRAW	= 8
FIF_PCD		= 9
FIF_PCX		= 10
FIF_PGM		= 11
FIF_PGMRAW	= 12
FIF_PNG		= 13
FIF_PPM		= 14
FIF_PPMRAW	= 15
FIF_RAS		= 16
FIF_TARGA	= 17
FIF_TIFF	= 18
FIF_WBMP	= 19
FIF_PSD		= 20
FIF_CUT		= 21
FIF_XBM		= 22
FIF_XPM		= 23
FIF_DDS		= 24
FIF_GIF         = 25
FIF_HDR		= 26


#Tiff compression types
TIFF_DEFAULT        = 0          # default format
TIFF_CMYK           = 0x0001	    # reads/stores tags for separated CMYK (use | to combine with compression flags)
TIFF_NONE           = 0x0800     # save without any compression
TIFF_PACKBITS       = 0x0100     # save using PACKBITS compression
TIFF_DEFLATE        = 0x0200     # save using DEFLATE compression (a.k.a. ZLIB compression)
TIFF_ADOBE_DEFLATE  = 0x0400 # save using ADOBE DEFLATE compression
TIFF_CCITTFAX3      = 0x1000     # save using CCITT Group 3 fax encoding
TIFF_CCITTFAX4      = 0x2000    # save using CCITT Group 4 fax encoding
TIFF_LZW            = 0x4000	# save using LZW compression
TIFF_JPEG           = 0x8000	# save using JPEG compression

#Jpeg compression types
JPEG_DEFAULT        = 0
JPEG_FAST           = 1
JPEG_ACCURATE       = 2
JPEG_QUALITYSUPERB  = 0x80
JPEG_QUALITYGOOD    = 0x100
JPEG_QUALITYNORMAL  = 0x200
JPEG_QUALITYAVERAGE = 0x400
JPEG_QUALITYBAD     = 0x800


#Dither transformation
FID_FS		 = 0     # Floyd & Steinberg error diffusion
FID_BAYER4x4	 = 1	    # Bayer ordered dispersed dot dithering (order 2 dithering matrix)
FID_BAYER8x8	 = 2	    # Bayer ordered dispersed dot dithering (order 3 dithering matrix)
FID_CLUSTER6x6	 = 3	    # Ordered clustered dot dithering (order 3 - 6x6 matrix)
FID_CLUSTER8x8	 = 4	    # Ordered clustered dot dithering (order 4 - 8x8 matrix)
FID_CLUSTER16x16 = 5	    # Ordered clustered dot dithering (order 8 - 16x16 matrix)

#Get_type
FIC_MINISWHITE = 0		# min value is white
FIC_MINISBLACK = 1		# min value is black
FIC_RGB        = 2		# RGB color model
FIC_PALETTE    = 3		# color map indexed
FIC_RGBALPHA   = 4		# RGB color model with alpha channel
FIC_CMYK       = 5		# CMYK color model

#Filter for rescale
FILTER_BOX	  = 0	# Box, pulse, Fourier window, 1st order (constant) b-spline
FILTER_BICUBIC	  = 1	# Mitchell & Netravali's two-param cubic filter
FILTER_BILINEAR   = 2	# Bilinear filter
FILTER_BSPLINE	  = 3	# 4th order (cubic) b-spline
FILTER_CATMULLROM = 4	# Catmull-Rom spline, Overhauser spline
FILTER_LANCZOS3	  = 5	# Lanczos3 filter

#Format type
FIT_UNKNOWN     = 0	    # unknown type
FIT_BITMAP      = 1	    # standard image			: 1-, 4-, 8-, 16-, 24-, 32-bit
FIT_UINT16	= 2	    # array of unsigned short	: unsigned 16-bit
FIT_INT16	= 3	    # array of short			: signed 16-bit
FIT_UINT32	= 4	    # array of unsigned long	: unsigned 32-bit
FIT_INT32	= 5	    # array of long			: signed 32-bit
FIT_FLOAT	= 6	    # array of float			: 32-bit IEEE floating point
FIT_DOUBLE	= 7	    # array of double			: 64-bit IEEE floating point
FIT_COMPLEX	= 8	    # array of FICOMPLEX		: 2 x 64-bit IEEE floating point
FIT_RGB16	= 9	    # 48-bit RGB image			: 3 x 16-bit
FIT_RGBA16	= 10	# 64-bit RGBA image		: 4 x 16-bit
FIT_RGBF	= 11	# 96-bit RGB float image	: 3 x 32-bit IEEE floating point
FIT_RGBAF	= 12	# 128-bit RGBA float image	: 4 x 32-bit IEEE floating point

#Metadata
FIMD_NODATA		= -1
FIMD_COMMENTS		= 0	    # single comment or keywords
FIMD_EXIF_MAIN		= 1	    # Exif-TIFF metadata
FIMD_EXIF_EXIF		= 2	    # Exif-specific metadata
FIMD_EXIF_GPS		= 3	    # Exif GPS metadata
FIMD_EXIF_MAKERNOTE     = 4	    # Exif maker note metadata
FIMD_EXIF_INTEROP	= 5	    # Exif interoperability metadata
FIMD_IPTC		= 6	    # IPTC/NAA metadata
FIMD_XMP		= 7	    # Abobe XMP metadata
FIMD_GEOTIFF		= 8	    # GeoTIFF metadata
FIMD_ANIMATION		= 9	    # Animation metadata
FIMD_CUSTOM		= 10    # Used to attach other metadata types to a dib

#FREE_IMAGE_COLOR_CHANNEL)
FICC_RGB	= 0	# Use red, green and blue channels
FICC_RED	= 1	# Use red channel
FICC_GREEN	= 2	# Use green channel
FICC_BLUE	= 3	# Use blue channel
FICC_ALPHA	= 4	# Use alpha channel
FICC_BLACK	= 5	# Use black channel
FICC_REAL	= 6	# Complex images: use real part
FICC_IMAG	= 7	# Complex images: use imaginary part
FICC_MAG	= 8	# Complex images: use magnitude
FICC_PHASE	= 9	# Complex images: use phase

#FREE_IMAGE_QUANTIZE
FIQ_WUQUANT = 0         #Xiaolin Wu color quantization algorithm
FIQ_NNQUANT = 1         # NeuQuant neural-net quantization algorithm by Anthony Dekker

#My costatants

#Colors used in a bitmap
COL_1  = 1
COL_4  = 4
COL_8  = 8
COL_16 = 16
COL_24 = 24
COL_32 = 32
COL_48 = 48
COL_64 = 64
COL_96 = 96
COL_1TO32 = (COL_1, COL_4, COL_8, COL_16, COL_24, COL_32)

#Return types
BYTE    = C.c_ubyte
VOID    = C.c_void_p
BOOL    = C.c_long
INT     = C.c_int
DWORD   = C.c_ulong
LONG    = C.c_long
WORD    = C.c_ushort


class FreeImagePy_LibraryNotFound(Exception):
    def __init__(self, value):
        self.value = value
    def __str__(self):
        return repr(self.value)

class FreeImagePy_ColorWrong(Exception):
    def __init__(self, value):
        self.value = value
    def __str__(self):
        return repr(self.value)


#Not done
"""
bmp = open('./logo.tif', 'rb')
image = C.create_string_buffer(bmp.read())
bmp.close()

READ_PROC = C.WINFUNCTYPE(C.c_char_p, C.c_void_p, C.c_uint, C.c_uint, C.c_uint)
def read_proc(buffer, size, count, bmp_handle):
    global image
    print type(buffer), buffer, size, count
    for i in range(count):
        buffer += image[:size]
    #print type(buffer), len (buffer)
    return count
    #print type(a)
    #print 'read', a,b,c,d

WRITE_PROC = C.WINFUNCTYPE(C.c_char_p, C.c_uint, C.c_uint, C.c_uint)
def write_proc(a,b,c,d):
    print 'write', a,b,c,d

SEEK_PROC = C.WINFUNCTYPE( C.c_char_p, C.c_uint, C.c_uint, C.c_uint)
def seek_proc(a,b,c):
    print 'seek', a,b,c

TELL_PROC = C.WINFUNCTYPE( C.c_char_p, C.c_uint)
def tell_proc(a):
    print 'tell', a

class FreeImageIO(C.Structure):
    _fields_ = [("read_proc", READ_PROC),
                ("write_proc", WRITE_PROC),
                ("seek_proc", SEEK_PROC),
                ("tell_proc", TELL_PROC)]

"""
